tonalitytools.OmissionIndicator
===============================

.. inheritance-diagram:: abjad.tools.tonalitytools.OmissionIndicator.OmissionIndicator.OmissionIndicator
   :private-bases:

.. autoclass:: abjad.tools.tonalitytools.OmissionIndicator.OmissionIndicator.OmissionIndicator

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.tonalitytools.OmissionIndicator.OmissionIndicator.OmissionIndicator.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Special Methods
---------------

.. automethod:: abjad.tools.tonalitytools.OmissionIndicator.OmissionIndicator.OmissionIndicator.__eq__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.tonalitytools.OmissionIndicator.OmissionIndicator.OmissionIndicator.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.tonalitytools.OmissionIndicator.OmissionIndicator.OmissionIndicator.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.tonalitytools.OmissionIndicator.OmissionIndicator.OmissionIndicator.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.tonalitytools.OmissionIndicator.OmissionIndicator.OmissionIndicator.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.tonalitytools.OmissionIndicator.OmissionIndicator.OmissionIndicator.__ne__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.tonalitytools.OmissionIndicator.OmissionIndicator.OmissionIndicator.__repr__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`
